@@ -36,6 +36,8 @@
 
 #include <gio/gio.h>
 #include <libxfce4ui/libxfce4ui.h>
+
+#include <exo/exo.h>
 #include <exo-desktop-item-edit/exo-die-editor.h>
 #include <exo-desktop-item-edit/exo-die-utils.h>
 
@@ -44,7 +46,7 @@
 #endif
 
 /* string with fallback spoort */
-#define STR_FB(string,fallback) ((string != NULL && *string != '\0') ? string : fallback)
+#define STR_FB(string, fallback) ((string != NULL && *string != '\0') ? string : fallback)
 
 
 
@@ -128,7 +130,6 @@ main (int argc, char **argv)
   GtkWidget       *chooser;
   GtkWidget       *message;
   GtkWidget       *button;
-  GtkWidget       *bbox;
   GtkWidget       *dialog;
   GtkWidget       *editor;
   GKeyFile        *key_file;
@@ -161,7 +162,7 @@ main (int argc, char **argv)
   g_log_set_always_fatal (G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING);
 #endif
 
-#if !GLIB_CHECK_VERSION(2,32,0)
+#if !GLIB_CHECK_VERSION(2, 32, 0)
   /* initialize the GThread system */
   if (!g_thread_supported ())
     g_thread_init (NULL);
@@ -246,10 +247,9 @@ main (int argc, char **argv)
       if (exo_str_is_equal (opt_type, G_KEY_FILE_DESKTOP_TYPE_LINK))
         {
           g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
-                                G_KEY_FILE_DESKTOP_KEY_ICON, STR_FB (opt_icon, "gnome-fs-bookmark"));
+                                G_KEY_FILE_DESKTOP_KEY_ICON, STR_FB (opt_icon, "bookmark-new"));
           g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
                                 G_KEY_FILE_DESKTOP_KEY_URL, STR_FB (opt_url, ""));
-
         }
       else if (exo_str_is_equal (opt_type, G_KEY_FILE_DESKTOP_TYPE_DIRECTORY))
         {
@@ -329,9 +329,7 @@ main (int argc, char **argv)
   gtk_window_set_icon_name (GTK_WINDOW (dialog), ICON_NAMES[mode]);
 
   button = gtk_button_new_with_mnemonic (_("_Help"));
-  bbox = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
-  gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, FALSE, 0);
-  gtk_button_box_set_child_secondary (GTK_BUTTON_BOX (bbox), button, TRUE);
+  exo_gtk_dialog_add_secondary_button(GTK_DIALOG (dialog), GTK_WIDGET (button));
   g_signal_connect (G_OBJECT (button), "clicked",
       G_CALLBACK (exo_die_help), dialog);
   gtk_widget_show (button);
