@@ -57,9 +57,9 @@
 /**
  * For testing this code, the following commands should work:
  *
- * exo-open --launch WebBrowser http://xfce.org (bug #5461).
- * exo-open --launch WebBrowser http://xfce.org bugs.xfce.org 'http://www.google.com/search?q=what is a space' 'http://wiki.xfce.org'
- * exo-open http://xfce.org
+ * exo-open --launch WebBrowser https://xfce.org (bug #5461).
+ * exo-open --launch WebBrowser https://xfce.org bugzilla.xfce.org 'http://www.google.com/search?q=what is a space' 'https://wiki.xfce.org'
+ * exo-open https://xfce.org
  * exo-open --launch TerminalEmulator ./script.sh 'something with a space' 'nospace' (bug #5132).
  * exo-open --launch TerminalEmulator ssh -l username some.host.com
  *
@@ -437,7 +437,11 @@ exo_open_uri (const gchar  *uri,
           && (strcmp (scheme, "ftp") == 0 || strcmp (scheme, "ftps") == 0))
         retval = exo_open_launch_category ("WebBrowser", uri);
       else
+#if GTK_CHECK_VERSION (3, 22, 0)
+        retval = gtk_show_uri_on_window (NULL, uri, 0, error);
+#else
         retval = gtk_show_uri (NULL, uri, 0, error);
+#endif
     }
 
   g_free (scheme);
