@@ -787,6 +787,11 @@ err1: /* initialize the library's i18n support */
       g_set_error (error, G_FILE_ERROR, g_file_error_from_errno (sverrno), _("Failed to open file \"%s\": %s"), display_name, g_strerror (sverrno));
       g_free (display_name);
 
+      if (fd >= 0)
+        {
+          close(fd);
+        }
+
       return NULL;
     }
 
