@@ -1,7 +1,5 @@
 #include <exo/exo-marshal.h>
-
-#include	<glib-object.h>
-
+#include <glib-object.h>
 
 #ifdef G_ENABLE_DEBUG
 #define g_marshal_value_peek_boolean(v)  g_value_get_boolean (v)
@@ -49,7 +47,6 @@
 #define g_marshal_value_peek_variant(v)  (v)->data[0].v_pointer
 #endif /* !G_ENABLE_DEBUG */
 
-
 /* VOID:INT,INT (exo-marshal.list:1) */
 void
 _exo_marshal_VOID__INT_INT (GClosure     *closure,
@@ -59,13 +56,13 @@ _exo_marshal_VOID__INT_INT (GClosure     *closure,
                             gpointer      invocation_hint G_GNUC_UNUSED,
                             gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer     data1,
-                                              gint         arg_1,
-                                              gint         arg_2,
-                                              gpointer     data2);
-  register GMarshalFunc_VOID__INT_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer data1,
+                                              gint arg1,
+                                              gint arg2,
+                                              gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__INT_INT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -96,13 +93,13 @@ _exo_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                   gpointer      invocation_hint G_GNUC_UNUSED,
                                   gpointer      marshal_data)
 {
-  typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer     data1,
-                                                    gpointer     arg_1,
-                                                    gpointer     arg_2,
-                                                    gpointer     data2);
-  register GMarshalFunc_VOID__OBJECT_OBJECT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer data1,
+                                                    gpointer arg1,
+                                                    gpointer arg2,
+                                                    gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_VOID__OBJECT_OBJECT callback;
 
   g_return_if_fail (n_param_values == 3);
 
@@ -127,18 +124,18 @@ _exo_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
 /* STRING:POINTER (exo-marshal.list:3) */
 void
 _exo_marshal_STRING__POINTER (GClosure     *closure,
-                              GValue       *return_value G_GNUC_UNUSED,
+                              GValue       *return_value,
                               guint         n_param_values,
                               const GValue *param_values,
                               gpointer      invocation_hint G_GNUC_UNUSED,
                               gpointer      marshal_data)
 {
-  typedef gchar* (*GMarshalFunc_STRING__POINTER) (gpointer     data1,
-                                                  gpointer     arg_1,
-                                                  gpointer     data2);
-  register GMarshalFunc_STRING__POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef gchar* (*GMarshalFunc_STRING__POINTER) (gpointer data1,
+                                                  gpointer arg1,
+                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_STRING__POINTER callback;
   gchar* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -166,19 +163,19 @@ _exo_marshal_STRING__POINTER (GClosure     *closure,
 /* STRING:STRING,STRING (exo-marshal.list:4) */
 void
 _exo_marshal_STRING__STRING_STRING (GClosure     *closure,
-                                    GValue       *return_value G_GNUC_UNUSED,
+                                    GValue       *return_value,
                                     guint         n_param_values,
                                     const GValue *param_values,
                                     gpointer      invocation_hint G_GNUC_UNUSED,
                                     gpointer      marshal_data)
 {
-  typedef gchar* (*GMarshalFunc_STRING__STRING_STRING) (gpointer     data1,
-                                                        gpointer     arg_1,
-                                                        gpointer     arg_2,
-                                                        gpointer     data2);
-  register GMarshalFunc_STRING__STRING_STRING callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef gchar* (*GMarshalFunc_STRING__STRING_STRING) (gpointer data1,
+                                                        gpointer arg1,
+                                                        gpointer arg2,
+                                                        gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_STRING__STRING_STRING callback;
   gchar* v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -207,17 +204,17 @@ _exo_marshal_STRING__STRING_STRING (GClosure     *closure,
 /* BOOLEAN:VOID (exo-marshal.list:5) */
 void
 _exo_marshal_BOOLEAN__VOID (GClosure     *closure,
-                            GValue       *return_value G_GNUC_UNUSED,
+                            GValue       *return_value,
                             guint         n_param_values,
                             const GValue *param_values,
                             gpointer      invocation_hint G_GNUC_UNUSED,
                             gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer     data1,
-                                                  gpointer     data2);
-  register GMarshalFunc_BOOLEAN__VOID callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__VOID) (gpointer data1,
+                                                  gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__VOID callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -244,19 +241,19 @@ _exo_marshal_BOOLEAN__VOID (GClosure     *closure,
 /* BOOLEAN:ENUM,INT (exo-marshal.list:6) */
 void
 _exo_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
-                                GValue       *return_value G_GNUC_UNUSED,
+                                GValue       *return_value,
                                 guint         n_param_values,
                                 const GValue *param_values,
                                 gpointer      invocation_hint G_GNUC_UNUSED,
                                 gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__ENUM_INT) (gpointer     data1,
-                                                      gint         arg_1,
-                                                      gint         arg_2,
-                                                      gpointer     data2);
-  register GMarshalFunc_BOOLEAN__ENUM_INT callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__ENUM_INT) (gpointer data1,
+                                                      gint arg1,
+                                                      gint arg2,
+                                                      gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__ENUM_INT callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
@@ -285,22 +282,22 @@ _exo_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
 /* BOOLEAN:INT,ENUM,BOOLEAN,ENUM,BOOLEAN (exo-marshal.list:7) */
 void
 _exo_marshal_BOOLEAN__INT_ENUM_BOOLEAN_ENUM_BOOLEAN (GClosure     *closure,
-                                                     GValue       *return_value G_GNUC_UNUSED,
+                                                     GValue       *return_value,
                                                      guint         n_param_values,
                                                      const GValue *param_values,
                                                      gpointer      invocation_hint G_GNUC_UNUSED,
                                                      gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__INT_ENUM_BOOLEAN_ENUM_BOOLEAN) (gpointer     data1,
-                                                                           gint         arg_1,
-                                                                           gint         arg_2,
-                                                                           gboolean     arg_3,
-                                                                           gint         arg_4,
-                                                                           gboolean     arg_5,
-                                                                           gpointer     data2);
-  register GMarshalFunc_BOOLEAN__INT_ENUM_BOOLEAN_ENUM_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
+  typedef gboolean (*GMarshalFunc_BOOLEAN__INT_ENUM_BOOLEAN_ENUM_BOOLEAN) (gpointer data1,
+                                                                           gint arg1,
+                                                                           gint arg2,
+                                                                           gboolean arg3,
+                                                                           gint arg4,
+                                                                           gboolean arg5,
+                                                                           gpointer data2);
+  GCClosure *cc = (GCClosure *) closure;
+  gpointer data1, data2;
+  GMarshalFunc_BOOLEAN__INT_ENUM_BOOLEAN_ENUM_BOOLEAN callback;
   gboolean v_return;
 
   g_return_if_fail (return_value != NULL);
