@@ -43,6 +43,18 @@
 
 
 
+/* resurrect dead gdk apis for Gtk3
+ * This is easier than using #ifs everywhere
+ */
+#if GTK_CHECK_VERSION (3, 0, 0)
+
+# ifdef gdk_cursor_unref
+#   undef gdk_cursor_unref
+# endif
+# define gdk_cursor_unref(cursor) g_object_unref (cursor)
+
+# endif
+
 #define EXO_TREE_VIEW_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
     EXO_TYPE_TREE_VIEW, ExoTreeViewPrivate))
 
@@ -373,13 +385,9 @@ exo_tree_view_button_press_event (GtkWidget      *widget,
         }
     }
 
-  /* see bug http://bugzilla.xfce.org/show_bug.cgi?id=6230 for more information */
   if (G_LIKELY (gtk_tree_selection_get_select_function (selection) == (GtkTreeSelectionFunc) exo_noop_false))
     {
-      /* just reset the select function (previously set to exo_noop_false),
-       * there's no clean way to do this, so what the heck.
-       */
-      gtk_tree_selection_set_select_function (selection, NULL, NULL, NULL);
+      gtk_tree_selection_set_select_function (selection, (GtkTreeSelectionFunc) exo_noop_true, NULL, NULL);
     }
 
   /* release the path (if any) */
@@ -516,7 +524,7 @@ exo_tree_view_motion_notify_event (GtkWidget      *widget,
               if (G_LIKELY (path != NULL))
                 {
                   /* setup the hand cursor to indicate that the row at the pointer can be activated with a single click */
-                  cursor = gdk_cursor_new (GDK_HAND2);
+                  cursor = gdk_cursor_new_for_display (gdk_window_get_display (event->window), GDK_HAND2);
                   gdk_window_set_cursor (event->window, cursor);
                   gdk_cursor_unref (cursor);
                 }
@@ -537,9 +545,9 @@ exo_tree_view_motion_notify_event (GtkWidget      *widget,
                   tree_view->priv->single_click_timeout_state = event->state;
 
                   /* schedule a new single-click timeout */
-                  tree_view->priv->single_click_timeout_id = g_timeout_add_full (G_PRIORITY_LOW, tree_view->priv->single_click_timeout,
-                                                                                 exo_tree_view_single_click_timeout, tree_view,
-                                                                                 exo_tree_view_single_click_timeout_destroy);
+                  tree_view->priv->single_click_timeout_id = gdk_threads_add_timeout_full (G_PRIORITY_LOW, tree_view->priv->single_click_timeout,
+                                                                                           exo_tree_view_single_click_timeout, tree_view,
+                                                                                           exo_tree_view_single_click_timeout_destroy);
                 }
             }
           else
@@ -643,8 +651,6 @@ exo_tree_view_single_click_timeout (gpointer user_data)
   GList             *rows;
   GList             *lp;
 
-  GDK_THREADS_ENTER ();
-
   /* verify that we are in single-click mode, have focus and a hover path */
   if (gtk_widget_has_focus (GTK_WIDGET (tree_view)) && tree_view->priv->single_click && tree_view->priv->hover_path != NULL)
     {
@@ -735,8 +741,6 @@ exo_tree_view_single_click_timeout (gpointer user_data)
         }
     }
 
-  GDK_THREADS_LEAVE ();
-
   return FALSE;
 }
 
